AndroidRenameSteps class

Constructors

AndroidRenameSteps(String newPackageName)

Properties

hashCode → int
The hash code for this object.
no setterinherited
newPackageName → String
final
oldPackageName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteEmptyDirs(String type) → Future<void>
dirContents(Directory dir) → Future<List<FileSystemEntity>>
findMainActivity({String type = 'java'}) → Future<File?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → Future<void>
processMainActivity(File path, String type) → Future<void>
toString() → String
A string representation of this object.
inherited
updateMainActivity() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited